@@ -92,9 +92,6 @@ extern "C" {
 #endif
 #include <signal.h>
 typedef void (*sig_t_)(int);
-#if !defined(_WIN32) && !defined(_WIN64) && !defined(_MSC_VER)
-    #include <unistd.h>
-#endif
 
 #ifdef _FOR_PYTHON
     /* This contains the standard cblas.h header */
